# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Prevent generation of debuginfo-related files not in package MANIFEST
%global debug_package %{nil}

Name:		perl-Perl-Critic
Version:	1.154
Release:	1.%{__distinit}%{__distvers}
Summary:	Critique Perl source code for best-practices
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Perl-Critic
Source0:	https://cpan.metacpan.org/modules/by-module/Perl/Perl-Critic-%{version}.tar.gz
Patch0:		0001-Change-default-spell-check-tool-from-aspell-to-hunsp.patch
Patch3:		Perl-Critic-1.136-ppidump-shellbang.patch
BuildArch:	noarch

# Build process
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Fatal)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::Build) >= 0.42

# Module requirements
BuildRequires:	hunspell >= 1.2.12
BuildRequires:	hunspell-en
BuildRequires:	perl(:VERSION) >= 5.10.1
BuildRequires:	perl(B::Keywords) >= 1.23
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config::Tiny) >= 2
BuildRequires:	perl(English)
BuildRequires:	perl(Exception::Class) >= 1.23
BuildRequires:	perl(Exporter) >= 5.58
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Spec::Unix)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(File::Which)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(List::SomeUtils) >= 0.55
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Module::Pluggable) >= 3.1
BuildRequires:	perl(parent)
BuildRequires:	perl(Perl::Tidy)
BuildRequires:	perl(Pod::PlainText)
BuildRequires:	perl(Pod::Select)
BuildRequires:	perl(Pod::Spell) >= 1
BuildRequires:	perl(Pod::Usage)
BuildRequires:	perl(PPI) >= 1.277
BuildRequires:	perl(PPIx::QuoteLike)
BuildRequires:	perl(PPIx::Regexp) >= 0.010
BuildRequires:	perl(PPIx::Regexp::Util) >= 0.068
BuildRequires:	perl(PPIx::Utils::Traversal) >= 0.003
BuildRequires:	perl(Readonly) >= 2
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(String::Format) >= 1.18
BuildRequires:	perl(Term::ANSIColor) >= 2.02
BuildRequires:	perl(Test::Builder) >= 0.92
BuildRequires:	perl(Text::ParseWords) >= 3
BuildRequires:	perl(version) >= 0.77
BuildRequires:	perl(warnings)

# Main test suite
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(Test::Memory::Cycle)
BuildRequires:	perl(Test::More)

# We don't run the author tests when bootstrapping due to circular dependencies
# Test::Perl::Critic obviously pulls in Perl::Critic too
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Devel::EnforceEncapsulation)
BuildRequires:	perl(Perl::Critic::Policy::Editor::RequireEmacsFileVariables)
BuildRequires:	perl(Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions)
BuildRequires:	perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
BuildRequires:	perl(Test::Kwalitee) >= 1.15
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Without::Module)
%endif

# Optional/not automatically detected runtime dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	hunspell >= 1.2.12
Requires:	perl(B::Keywords) >= 1.23
Requires:	perl(File::Which)
Requires:	perl(Module::Pluggable) >= 3.1
Requires:	perl(PPI) >= 1.277
Requires:	perl(Term::ANSIColor) >= 2.02

%description
Perl::Critic is an extensible framework for creating and applying coding
standards to Perl source code. Essentially, it is a static source code
analysis engine. Perl::Critic is distributed with a number of
Perl::Critic::Policy modules that attempt to enforce various coding
guidelines. Most Policy modules are based on Damian Conway's book Perl
Best Practices. However, Perl::Critic is not limited to PBP and will
even support Policies that contradict Conway. You can enable, disable,
and customize those Polices through the Perl::Critic interface. You can
also create new Policy modules that suit your own tastes.

%package -n perl-Test-Perl-Critic-Policy
Summary:	A framework for testing your custom Policies
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
Requires:	perl(Test::Builder) >= 0.92

%description -n perl-Test-Perl-Critic-Policy
This module provides a framework for function-testing your custom
Perl::Critic::Policy modules. Policy testing usually involves feeding it a
string of Perl code and checking its behavior. In the old days, those strings
of Perl code were mixed directly in the test script. That sucked.

%prep
%setup -q -n Perl-Critic-%{version}

# Switch spell checker tool from aspell to hunspell
%patch -P 0 -p1

# Fix shellbang in ppidump tool
%patch -P 3

# Drop exec bits from samples/docs to avoid dependency bloat
find tools examples -type f -exec chmod -c -x {} ';'

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
LC_ALL=en_US ./Build %{!?perl_bootstrap:author}test

%files
%license LICENSE
%doc Changes CONTRIBUTING.md README TODO.pod examples/ extras/ tools/
%{_bindir}/perlcritic
%{perl_vendorlib}/Perl/
%{_mandir}/man1/perlcritic.1*
%{_mandir}/man3/Perl::Critic*.3*

%files -n perl-Test-Perl-Critic-Policy
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Perl::Critic::Policy.3*

%changelog
* Mon Oct 21 2024 Paul Howarth <paul@city-fan.org> - 1.154-1
- Update to 1.154 (rhbz#2320114)
  Enhancements
  - ProhibitedUnusedCapture now recognizes %%+, %%-, %%{^CAPTURE} and
    %%LAST_PAREN_MATCH (GH#1065)
  - Fixed a deprecation warning in the extras/perlcritic.el Emacs script
    (GH#1067)
  - RequireExplicitPackage now accepts a use VERSION as the first line
    (GH#1070)
  Fixes
  - Fix some false positives for function calls as a hash index (GH#1071)
  Documentation
  - Clarify package_exemptions rules (GH#1043)

* Sun Jul 21 2024 Paul Howarth <paul@city-fan.org> - 1.152-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Fri Jan 26 2024 Paul Howarth <paul@city-fan.org> - 1.152-3
- Re-rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild
  (see https://pagure.io/releng/issue/11888)

* Mon Jan 22 2024 Paul Howarth <paul@city-fan.org> - 1.152-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Oct 17 2023 Paul Howarth <paul@city-fan.org> - 1.152-1
- Update to 1.152 (rhbz#2244582)
  - Fix a test failure for Subroutines::RequireArgUnpacking (GH#1048)
  - Fix a test failure in t/06_violation.t on Perl 5.39.1 or above (GH#1037)

* Mon Sep 25 2023 Paul Howarth <paul@city-fan.org> - 1.150-4
- Fix for Perl::Critic::Policy::Subroutines::RequireArgUnpacking with PPI 1.277
  (GH#1048)

* Fri Jul 21 2023 Paul Howarth <paul@city-fan.org> - 1.150-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Mon Jul 10 2023 Paul Howarth <paul@city-fan.org> - 1.150-2
- Use SPDX-format license tag for perl-Test-Perl-Critic-Policy sub-package
- Avoid use of deprecated patch syntax

* Sun Mar  5 2023 Paul Howarth <paul@city-fan.org> - 1.150-1
- Update to 1.150 (rhnz#2175475)
  Enhancements
  - Added Test::Builder and Text::Wrap to the list of default exceptions in
    Variables::ProhibitPackageVars (GH#1025)
  Internals
  - We now use PPIx::Utils instead of PPIx::Utilities, which is more recently
    maintained

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 1.148-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Jan  8 2023 Paul Howarth <paul@city-fan.org> - 1.148-1
- Update to 1.148
  Possible breakage
  - Removed Perl::Critic::Utils::DataConversion; any add-on policies that used
    it will need to copy the functions from there into their own code
  Documentation
  - ProhibitCascadingIfElse no longer suggests using given/when
  Internals
  - We no longer require Test::Deep for testing
  - Test::Kwalitee is now only recommended, not required
  - Random micro-optimizations, like using hashes for array contents checking,
    and using any() instead of calling grep as a boolean

* Thu Dec 22 2022 Paul Howarth <paul@city-fan.org> - 1.146-1
- Update to 1.146
  New features
  - ProhibitBarewordDirHandles now checks for sysopen as well as open (GH#732)
  - Added a Dockerfile in the extras/ directory for those who want to run P::C
    in a container (GH#832)
  - Subroutines::ProhibitBuiltinHomonyms now can take an "allows" parameter to
    specify subroutines that won't violate the policy (GH#14, GH#932)
  - ProhibitStringyEval now allows package declarations in evals when
    allow_includes = true; this is a common way packages are declared (GH#908)
  Bug Fixes
  - Fixed some problems with how Perl::Critic determined scope (GH#793)
  - Fixed improper violation for lexical subroutines in
    Subroutines::ProhibitBuiltinHomonyms (GH#973, GH#955, GH#546)
  - ValuesAndExpressions::RequireNumberSeparators no longer complains if your
    version numbers do not have number separators in them (GH#856, GH#904)
  - Fixed a false positive with split() in ProhibitUnusedCapture (GH#888)
  Internals
  - We no longer use or need IO::String (GH#997)
  - Removed requirements and mentions of modules no longer used:
    - Fatal
    - IO::String
    - IPC::Open2
    - Pod::Parser
    - Task::Weaken

* Tue Dec  6 2022 Paul Howarth <paul@city-fan.org> - 1.144-1
- Update to 1.144
  - Perl::Critic now requires Perl 5.10.1
  New features
  - The ProhibitAugmentedAssignmentInDeclaration policy now allows augmented
    assignments to "our" variables, if the allow_our option is enabled (GH#993)
  - ProhibitExplicitISA now recommends "use parent" instead of "use base"
    (GH#987)
  - RequireUseWarnings now recognizes that "use v5.36" implies warnings (GH#984)
  - Subroutines::ProhibitNestedSubs now allows that lexical subroutines can be
    inside other subroutines (GH#946, GH#971, GH#972)
  - RequireUseStrict now knows that Test::Spec enables it (GH#906)
  - ProhibitUnusedCapture now understands @{^CAPTURE} and %%{^CAPTURE_ALL} that
    were added in Perl 5.26.0 (GH#778)
  - Allow numeric operators on special number strings 'NaN' and 'inf' (GH#803)
  Fixes
  - Miscellanea::ProhibitUselessNoCritic no longer filters out errors about
    itself, just as Miscellanea::ProhibitUnrestrictedNoCritic cannot (GH#939)
  - Fixed GH#878: bareword filehandle dies on "open(CHECK, '/foo');"
  Internals
  - Updated to using Perl 5.10.1; starting migrating to Perl 5.10-isms like
    defined-or
  Documentation
  - Updated some outdated docs in Perl::Critic::Utils (GH#951)

* Tue Nov 29 2022 Paul Howarth <paul@city-fan.org> - 1.142-1
- Update to 1.142
  - This is the last version of Perl::Critic that will run on Perl 5.6.1; the
    next release will require Perl 5.10.1
  New Features
  - Add new policy InputOutput::ProhibitBarewordDirHandles, comparable to
    ProhibitBarewordFilehandles (GH#912)
  - References::ProhibitDoubleSigils policy now allows for Perl's postfix
    dereference syntax and does not report a policy violation (GH#578)
  - Added Test::Class::Moose and MooseX::MethodAttributes::Role to the list of
    modules that are equivalent to "use strict" (GH#808, GH#886)
  - Subroutines::RequireArgUnpacking now detects anonymous subroutines with
    attributes, prototypes or signatures (GH#684)
  - ProhibitVoidMap and ProhibitVoidGrep now detect void context inside subs
    (GH#905), such as: sub { map { foo($_) } @list; return }
  - RequireArgUnpacking now allows a closure to be recognized as a way that
    subroutine arguments can be unpacked; this is specified with an optional
    allow_closures configuration option (GH#737)
  - ProhibitTwoArgOpen now disallows one-arg opens as well; also, it no longer
    allows two-arg opening of STDIN/STDOUT/STDERR (GH#652, GH#653)
  Fixes
  - ProhibitLeadingZeros would not handle sysopen and lexical variables
    correctly; this has been fixed (GH#789)
  Documentation
  - We note that the any() function is available in both List::MoreUtils and
    List::SomeUtils
  - Added instructions to perlcritic on how to integrate with Visual Studio
    Code
  Internals
  - Switch to using List::SomeUtils instead of List::MoreUtils
- Use SPDX-format license tag

* Wed Mar 24 2021 Paul Howarth <paul@city-fan.org> - 1.140-1
- Update to 1.140
  - Subroutines::RequireFinalReturn now lets you specify a terminal_methods
    parameter to specify methods that should be seen as terminal; this is like
    the terminal_funcs parameter, but for methods (GH#920)
  - Removed an extra /x in RequireInterpolationOfMetachars.pm that caused
    deprecation warnings in Perl 5.22 and higher  (GH#822)
  - Documentation::RequirePackageMatchesPodName now recognizes the package
    name if it's in 'I<>' or 'B<>' markup (GH#913)
- Always use hunspell as spell-checker
- Use %%license unconditionally

* Sat Jul 11 2020 Paul Howarth <paul@city-fan.org> - 1.138-5
- Add workaround for 'Subroutine name is a homonym for builtin function isa'
  (#1852437, GH#911)

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 1.138-4
- Perl 5.32 rebuild

* Sat Jan 25 2020 Paul Howarth <paul@city-fan.org> - 1.138-1
- Update to 1.138
  - RequireCheckingReturnValueOfEval didn't count returning the result of an
    eval as checking it - now it does; however, it's only if you "return eval
    { ... }" - it still doesn't handle the case of "return ( eval {} )"
    (GH#324)
  - ProhibitPunctuationVars would get confused and think that the expression
    qr/SOME$/ was using the $/ special variable (GH#843)

* Thu Nov 28 2019 Paul Howarth <paul@city-fan.org> - 1.136-1
- Update to 1.136
  New Features
  - The ProhibitNoWarnings policy now handles warnings in the experimental::
    group (GH#892)
  Documentation
  - Prevented some example code from showing up in 'perldoc' (GH#799)
- Fix shellbang in ppidump tool

* Sat Oct 19 2019 Paul Howarth <paul@city-fan.org> - 1.134-5
- Fix #822: 'Having more than one /x regexp modifier is deprecated'
  https://github.com/reneeb/Perl-Critic/commit/383640d3
  https://github.com/Perl-Critic/Perl-Critic/issues/822

* Fri Jul 26 2019 Paul Howarth <paul@city-fan.org> - 1.134-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Jun  8 2019 Paul Howarth <paul@city-fan.org> - 1.134-3
- Perl 5.30 rebuild

* Thu May 23 2019 Paul Howarth <paul@city-fan.org> - 1.134-1
- Update to 1.134
  New Features
  - Added new policy BuiltinFunctions::ProhibitShiftRef (GH#837)
  - Support indented heredocs (GH#861)
  - In Subroutines::ProhibitManyArgs, you can now omit the object variable
    (C<$self> or C<$class>) from the argument count (GH#815)
  Policy Changes
  - The policy Documentation::RequirePodLinksIncludeText is obsolete and has
    been removed (GH#494)
  Dependencies
  - Removed use of File::HomeDir
  - Upgrade to PPI 1.265 (GH#860)
  - Fix failed tests caused by new PPI (GH#858)
  Internals
  - Updated the Appveyor config (GH#851)

* Mon Apr 29 2019 Paul Howarth <paul@city-fan.org> - 1.132-8
- Add workaround for PPI ≥ 1.262

* Fri Apr 26 2019 Paul Howarth <paul@city-fan.org> - 1.132-7
- Add workaround for PPI ≥ 1.250
  https://github.com/Perl-Critic/Perl-Critic/issues/858

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1.132-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Nov  6 2018 Paul Howarth <paul@city-fan.org> - 1.132-5
- Explicitly BR: glibc-langpack-en

* Fri Jun  1 2018 Paul Howarth <paul@city-fan.org> - 1.132-1
- Update to 1.132
  New Features
  - In the ProhibitLeadingZeros policy, added an exception for mkfifo (GH#786)
  - Add colour support for Windows platforms (GH#700)
  - Perl::Critic now assumes that .psgi files are Perl, too (GH#805)
  - Variables::ProhibitUnusedVariables no longer gives a false positive for
    variables used in interpolation (GH#801)
  - Added the ability to specify a regex to tell what unused private
    subroutines are OK in Subroutines::ProhibitUnusedPrivateSubroutines; this
    is handy for Moose classes where there could be many false positives on
    _build_xxxx() subroutines (GH#811, GH#812)
  Dependencies
  - Perl::Critic now no longer relies on the deprecated Email::Address
    (GH #816)
  Bug Fixes
  - Recode Perl::Critic::Utils::all_perl_files() to use File::Find instead of
    opendir/readdir; this solves endless directory traversals if the
    directories contain circular symbolic references
  - Added missing requirement for Fatal.pm
  Documentation
  - Added CONTRIBUTING.md
- Switch upstream from search.cpan.org to metacpan.org

* Fri Jul 21 2017 Paul Howarth <paul@city-fan.org> - 1.130-2
- Switch spell checker tool from aspell to hunspell if we have a recent
  enough version

* Fri Jul 21 2017 Paul Howarth <paul@city-fan.org> - 1.130-1
- Update to 1.130
  New Features
  - Policies that ensure that system calls are checked, such as
    RequireCheckedSystemCalls, now have an "autodie_modules" setting that
    allows you to tell the policy about other modules that export autodie
    (GH#699, GH#747)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1.128-1
- Update to 1.128
  Bug Fixes
  - PPI misparsing a module caused an incorrect "Must end with a recognizable
    true value"; this is fixed by upgrading to PPI 1.224 (GH#696, GH#607)
  - A test would fail under the upcoming Perl 5.26 that omits the current
    directory from @INC
  - Fixed an invalid test in the RequireBarewordsIncludes test (GH#751)
  - If an element contained blank lines then the source "%%r" displayed for a
    violation was wrong (GH#702, GH#734)
  Dependencies
  - Perl::Critic now requires PPI 1.224; PPI is the underlying Perl parser on
    which Perl::Critic is built, and 1.224 introduces many parsing fixes such
    as:
    - Fixes for dot-in-@INC
    - Parse left side of => as bareword even if it looks like a keyword or op
    - $::x now works
    - Higher accuracy when deciding whether certain characters are operators or
      variable type casts (*&%% etc.)
    - Subroutine attributes parsed correctly
  Performance Enhancements
  - Sped up BuiltinFunctions::ProhibitUselessTopic ~7%% (GH#656)
  Documentation
  - Fixed incorrect explanation of capture variables in
    ProhibitCaptureWithoutTest
  - Fixed incorrect links
  - Fixed incorrect example for returning a sorted list
  - Fixed invalid POD (GH#735)
  - Updated docs on ProhibitYadaOperator (GH#662)
  - Removed all the references to the old mailing list and code repository at
    tigris.org (GH#757)
- This release by PETDANCE → update source URL

* Wed May 24 2017 Paul Howarth <paul@city-fan.org> - 1.126-6
- Fix t/07_perlcritic.t for @INC without '.' (GH#738)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88
  - Always build perl-Test-Perl-Critic-Policy
  - Can always run kwalitee test now

* Tue Sep 20 2016 Paul Howarth <paul@city-fan.org> - 1.126-4
- BR: perl-generators where available

* Tue Aug 11 2015 Paul Howarth <paul@city-fan.org> - 1.126-1
- Update to 1.126
  - Added a policy: ControlStructures::ProhibitYadaOperator - Never use ... in
    production code
  - Fixed problems arising from having -b in your .perltidyrc file
  - Removed extra newline from policy names returned by P::C::Config->policies
  - 'fc' and 'say' are now covered by ProhibitUselessTopic
  - Add more strict/warnings importer modules
  - Path::Tiny is now recommended over File::Slurp
  - Micro-optimize by calling ->content() directly instead of going through the
    overloads
  - Square brackets are now allowed around your '## no critic' policy list

* Mon Jun 29 2015 Paul Howarth <paul@city-fan.org> - 1.125-4
- Perl 5.22 rebuild

* Tue Mar  3 2015 Paul Howarth <paul@city-fan.org> - 1.125-1
- Update to 1.125
  - Corrected dependency on List::Util::any() to List::MoreUtils::any()
  - Revised and updated documentation
- Drop upstreamed patch for GH #626

* Sat Feb 28 2015 Paul Howarth <paul@city-fan.org> - 1.124-1
- Update to 1.124
  - The ProhibitUnusedPrivateSubroutines policy can now ignore files that use
    particular modules with the 'skip_when_using' option, which allows, for
    example, skipping the policy for roles
  - The RequireUseStrict and RequireUseWarnings policies now regard Moose, Moo,
    Mouse, Dancer, Mojolicious, and several other modules as equivalent to the
    strict and warnings pragma
  - The RequireChecked* family of policies has been fixed to accommodate
    version numbers when use-ing the autodie pragma (GH #612)
- Add patch to avoid the need for List::Util ≥ 1.33 (GH #626)

* Wed Nov 12 2014 Paul Howarth <paul@city-fan.org> - 1.123-1
- Update to 1.123
  - Now requires PPI-1.220 which has numerous bug fixes; this may eliminate
    the need for some "## no critic" markers you inserted to work around those
    bugs - the "ProhibitUselessNoCritic" policy should help you find them
  - Fixed a typo in the Variables::ProhibitPerl4PackageNames message

* Tue Sep 16 2014 Paul Howarth <paul@city-fan.org> - 1.122-2
- Perl 5.20 rebuild

* Mon Aug 25 2014 Paul Howarth <paul@city-fan.org> - 1.122-1
- Update to 1.122
  - Now requires PPI-1.218, which has numerous enahncements and bug fixes
  - Also now requires Readonly-2.00, which obviates the need for Readonly::XS
    to get fast constants
  - File::HomeDir, File::Which, and Term::ANSIColor are all required now
    instead of being optional or recommended; this simplifies our test code
    and ensures consistent optimal behavior for all users
  - Added two new policies: BuiltinFunctions::ProhibitUselessTopic and
    RegularExpressions::ProhibitUselessTopic
  - Updated the perlcritic.el script to use modern Emacs hooks (GH #556)
  - Removed all the internal RCS keyword boilerplate blocks that were never
    getting expanded
- Use %%license where possible
- Drop upstreamed patches
- Drop patch for building with old Term::ANSIColor, no longer needed

* Fri May  2 2014 Paul Howarth <paul@city-fan.org> - 1.121-3
- Add upstream fix for Build.PL to work with current toolchain, and reinstate
  use of "Build authortest"

* Wed Apr 30 2014 Paul Howarth <paul@city-fan.org> - 1.121-2
- xt/author/82_optional_modules.t shouldn't be trying to use Readonly::XS (#1092921)
- Run the author tests using "Build test" rather than "Build authortest" because the
  latter ends up deleting META.yml and that causes the kwalitee test to fail
- Drop %%defattr, redundant since rpm 4.4

* Sun Nov  3 2013 Paul Howarth <paul@city-fan.org> - 1.121-1
- Update to 1.121
  - Added new themes based on CERT guidelines
  - The source code repository for Perl-Critic has been moved to GitHub at
    http://github.com/Perl-Critc/Perl-Critic; all tickets from the RT queue
    have also been moved there - please use GitHub for submitting any new bugs
    or corresponding about existing ones
  - The change log was reformatted to comply with CPAN::Changes::Spec
- BR: perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords) for the
  extra tests
- Don't try to run the kwalitee test unless we can support a recent enough
  Test::Kwalitee

* Sat Oct 26 2013 Paul Howarth <paul@city-fan.org> - 1.120-1
- Update to 1.120
  - Fix precedence error in Perl::Critic::Utils (CPAN RT#88866)

* Thu Sep 26 2013 Paul Howarth <paul@city-fan.org> - 1.119-1
- Update to 1.119
  - Tests were failing with Config::Tiny 2.17 or later, due to a change in the
    error messages produced by that module (CPAN RT#88679, CPAN RT#88889,
    https://github.com/Perl-Critic/Perl-Critic/pull/16)
  - BuiltinFunctions::ProhibitVoidGrep and ::ProhibitVoidMap: grep and map
    called as functions are now allowed in slice operations (CPAN RT#79289)
  - Subroutines::RequireArgUnpacking: most tests of the size of @_ are now
    allowed (CPAN RT#79138)
  - Modernized our usage of Exporter (CPAN RT#75300)

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 1.118-5
- Perl 5.18 rebuild

* Thu Jun 20 2013 Paul Howarth <paul@city-fan.org> - 1.118-4
- BR: perl(Fatal) for the test suite

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.118-2
- perl 5.16 post-bootstrap rebuild

* Wed Jul 11 2012 Paul Howarth <paul@city-fan.org> - 1.118-1
- update to 1.118
  Policy Changes:
  - CodeLayout::RequireTidyCode: revise to work with incompatible changes in
    Perl::Tidy 20120619 (CPAN RT#77977)
  - TestingAndDebugging::ProhibitNoWarnings: correct the parse of the
    'no warnings' statement, so that 'no warnings "qw"' is recognized as
    suppressing just 'qw' warnings (CPAN RT#74647)
  - Miscellanea::RequireRcsKeywords has been moved to the Perl-Critic-More
    distribution (CPAN RT#69546)
  Other Changes:
  - make all unescaped literal "{" characters in regexps into character
    classes; these are deprecated, and became noisy with Perl 5.17.0
    (CPAN RT#77510)
- drop now-redundant patch for Perl::Tidy compatibility
- don't create perl-Test-Perl-Critic-Policy unless we have
  perl(Test::Builder) ≥ 0.82, and add a dependency for it
- BR: perl(lib) for the build process
- BR: perl(base) and perl(PPIx::Utilities::Node) for the module
- BR: perl(File::Spec::Functions) for the test suite
- drop buildreqs for perl(charnames), perl(File::Basename), perl(File::Find),
  perl(overload), perl(strict) and perl(warnings) - not dual lived

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 1.117-5
- fix breakage with Perl::Tidy ≥ 20120619 (CPAN RT#77977)

* Thu Mar  1 2012 Paul Howarth <paul@city-fan.org> - 1.117-4
- bundle Test::More, Test::Builder and Test::Builder::Module 0.92 and put them
  in inc/; this enables us to get Perl::Critic built and tested OK on RHEL-4
  and similarly old distributions, and other workarounds aren't needed
- BR: perl(Exporter) ≥ 5.58; with older versions we get:
  ":color_severity" is not exported by the Perl::Critic::Utils::Constants module

* Tue Feb 28 2012 Paul Howarth <paul@city-fan.org> - 1.117-3
- reshuffle buildreqs to resync with Rawhide package
- drop redundant %%{?perl_default_filter}

* Thu Dec 22 2011 Paul Howarth <paul@city-fan.org> - 1.117-1
- update to 1.117
  New Policies:
  - Variables::ProhibitAugmentedAssignmentInDeclaration reports constructs like
    'my $x += 1'
  Policy Changes:
  - BuiltinFunctions::ProhibitLvalueSubstr: add explicit 'use version'
    (CPAN RT#68498)
  - CodeLayout::ProhibitHardTabs: add 'pbp' to the default_themes list
    (CPAN RT#71093)
  - ControlStructures::ProhibitMutatingListFunctions now understands that
    tr///r (introduced in 5.13.7) does not change its operand
  - ControlStructures::ProhibitMutatingListFunctions now understands that
    '//=', '<<=', and '>>=' are assignment operators (CPAN RT#70901)
  - ErrorHandling::RequireCheckingReturnValueOfEval now allows things
    like grep { eval $_ } (CPAN RT#69489)
  - Modules::RequireExplicitPackage now has configuraion option
    allow_import_of, to allow the import of specified modules before the
    package statement (CPAN RT#72660)
  - RegularExpressions::ProhibitEnumeratedClasses no longer thinks
    that [A-Za-z_] matches \w. RT #69322.
  - RegularExpressions::ProhibitUnusedCaptures now skips the first block of
    an 'if' or 'elsif' if the regular expression is bound to its operand with
    the '!~' operator (CPAN RT#69867)
  - RegularExpressions::ProhibitUnusedCaptures now looks into lists and blocks
    in the replacement portion of the regular expression if /e is asserted
    (CPAN RT#72086)
  - RegularExpressions::RequireDotMatchAnything,
    RegularExpressions::RequireExtendedFormatting and
    RegularExpressions::RequireLineBoundaryMatching now honor defaults set with
    'use re "/modifiers"' (CPAN RT#72151)
  - Subroutines::ProhibitManyArgs now recognizes '+' as a prototype character
  - Variables::ProhibitPunctuationVars now recognizes bracketed variables
    embedded in interpolated strings (e.g. "${$}"); for the purpose of the
    'allow' configuration, these are considered equivalent to the unbracketed
    form (CPAN RT#72910)
  Other Changes:
  - corrected POD in Perl::Critic::PPI::Utils (CPAN RT#68898)
  - Perl::Critic::Violation source() method now returns the line containing
    the violation (not the first line) when the statement containing the
    violation spans multiple lines
- this release by THALJEF -> update source URL
- drop stopwords patch, now included upstream

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1.116-3
- rebuild for perl 5.14.1 in Rawhide
- add support for perl_bootstrap macro
- fix dist tag for CentOS 6 and Scientific Linux

* Mon May 16 2011 Paul Howarth <paul@city-fan.org> - 1.116-1
- update to 1.116
  - BuiltInFunctions::ProhibitLvalueSubstr does not report violations if the
    document contains an explicit 'use n.nnn;' where the version is before
    5.005 (CPAN RT#59112)
  - Documentation::RequirePodSections no longer blows up on code having POD but
    no =head1 (CPAN RT#67231)
  - RegularExpressions::ProhibitUnusedCapture should more reliably find things
    like s/(a)/${1}2/ (CPAN RT#67273)
  - ValuesAndExpressions::ProhibitMagicNumbers and Module::RequireVersionVar
    now treat versions passed as the second argument of a 'package' statement
    the same as versions declared as 'our $VERSION ...' (CPAN RT#67159)
  - Variables::RequireLexicalLoopIterators does not report violations if the
    document contains an explicit 'use n.nnn;' where the version is before
    5.004 (CPAN RT#67760)

* Fri Apr  1 2011 Paul Howarth <paul@city-fan.org> - 1.115-1
- update to 1.115
  - fatal error in RegularExpressions::ProhibitUnusedCapture here document
    check (CPAN RT#67116)
  - internal POD error in Documentation::RequirePodLinksIncludeText
    (CPAN RT#67012)

* Tue Mar 29 2011 Paul Howarth <paul@city-fan.org> - 1.114-2
- switch to Module::Build flow, preferred by upstream
- drop unused buildreq perl(Test::Spelling)
- add runtime dependency on aspell
- add buildreqs for completeness:
  - perl(Carp)
  - perl(charnames)
  - perl(Exporter)
  - perl(File::Basename)
  - perl(File::Find)
  - perl(File::Path)
  - perl(File::Spec)
  - perl(File::Spec::Unix)
  - perl(File::Temp)
  - perl(Getopt::Long)
  - perl(List::Util)
  - perl(overload)
  - perl(Pod::PlainText)
  - perl(Pod::Select)
  - perl(Pod::Usage)
  - perl(Readonly::XS)
  - perl(Scalar::Util)
  - perl(strict)
  - perl(Test::More)
  - perl(warnings)
- add version requirement of 1 for perl(Pod::Spell)
- add version requirement of 0.010 for perl(PPIx::Regexp)
- add version requirement of 1.00 for perl(Test::Pod)
- add version requirement of 1.04 for perl(Test::Pod::Coverage)
- add version requirement of 3 for perl(Text::ParseWords)
- drop explicit dependencies on perl(Perl::Tidy), perl(Pod::Spell),
  perl(PPIx::Regexp) and perl(Text::ParseWords) - all detected automatically

* Sun Mar 27 2011 Paul Howarth <paul@city-fan.org> 1.114-1
- update to 1.114
  - Documentation::RequirePodLinksIncludeText now handles nested POD formatting
    (CPAN RT#65569)
  - clarified relation of severity numbers to names in Perl::Critic POD
    (CPAN RT#66017)
  - removed caveats from Variables::RequireLocalizedPunctuationVars, no longer
    necessary with PPI 1.208 (CPAN RT#65514)
  - have InputOutput::RequireBriefOpen attempt to expand scope as necessary to
    deal with the case where the open() and the corresponding close() are not
    in the same scope (CPAN RT#64437)
  - RegularExpressions::ProhibitUnusedCapture now looks inside double-quotish
    things (CPAN RT#38942)
  - RegularExpressions::ProhibitUnusedCapture now takes logical alternation
    into account, so that (e.g.)
	if ( /(a)/ || /(b)/ ) {
		say $1;
	}
    is not a violation. RT #38942.
  - ValuesAndExpressions::ProhibitCommaSeparatedStatements now recognizes
    'return { foo => 1, bar => 2 }' as containing a hash constructor, not a
    block; this was fixed by PPI 1.215 (CPAN RT#61301)
  - ValuesAndExpressions::ProhibitCommaSeparatedStatements now recognizes
    'bless { foo => 1, bar => 2 }' as containing a hash constructor, not a
    block; this was fixed by PPI 1.215 (CPAN RT#64132)
- bump PPI version requirement to 1.215
- BR/R: perl(Pod::Parser)
- nobody else likes macros for commands

* Fri Mar 18 2011 Paul Howarth <paul@city-fan.org> 1.113-2
- add lots more buildreqs to improve test coverage
- run author tests as well as main test suite
- split Test::Perl::Critic::Policy off into its own package

* Tue Feb 15 2011 Paul Howarth <paul@city-fan.org> 1.113-1
- update to 1.113 (see Changes for details)

* Thu Dec 16 2010 Paul Howarth <paul@city-fan.org> 1.111-2
- BR/R: perl(Pod::Spell) and perl(PPIx::Regexp)
- R: perl(File::Which)
- bump perl(PPI) requirement to 1.208

* Wed Dec 15 2010 Paul Howarth <paul@city-fan.org> 1.111-1
- update to 1.111
  - work around change in List::MoreUtils 0.28 that broke ProhibitNoStrict and
    ProhibitNoWarnings (CPAN RT#63816)

* Mon Sep  6 2010 Paul Howarth <paul@city-fan.org> 1.109-1
- update to 1.109 (ValuesAndExpressions::RequireInterpolationOfMetachars fix
  due to changes in Email::Address 1.890; note that this may find problems in
  code that it didn't before, e.g. q<'@foo'>)

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> 1.108-1
- update to 1.108 (see Changes for details)
- buildreq perl(Task::Weaken) and perl(PPIx::Utilities::Statement)
- package Test::Perl::Critic::Policy
- drop shellbang patch, no longer needed
- drop manual dependency on perl(Email::Address), no longer needed
- skip t/20_policies.t if we don't have Test::Builder >= 0.82

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> 1.106-1
- update to 1.106
  - NamingConventions::Capitalization fix for PPI 1.212 (CPAN RT #57348)
- BR: perl(Email::Address) and perl(Test::Perl::Critic)
- update shellbang patch
- drop patch for CPAN RT#57348, no longer needed

* Mon May 10 2010 Paul Howarth <paul@city-fan.org> 1.105-4
- add patch to un-break test suite with PPI >= 1.212 (CPAN RT#57348)
- add patch to fix a shellbang to placate rpmlint
- fix dist tag to work with RHEL6 Beta

* Fri Jan 29 2010 Paul Howarth <paul@city-fan.org> 1.105-3
- buildreq perl(Test::Deep), perl(Test::Spelling), aspell-en for better
  test coverage
- use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Wed Nov 25 2009 Paul Howarth <paul@city-fan.org> 1.105-2
- import from Fedora

* Wed Oct  7 2009 Stepan Kasal <skasal@redhat.com> 1.105-1
- new upstream version
- update build requires

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1.098-3
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun May 17 2009 Chris Weyl <cweyl@alumni.drew.edu> 1.098-1
- "neaten" filtering
- auto-update to 1.098 (by cpan-spec-update 0.01)
- added a new br on perl(strict) (version 0)
- added a new br on perl(Scalar::Util) (version 0)
- added a new br on perl(File::Temp) (version 0)
- added a new br on perl(Pod::Usage) (version 0)
- added a new br on perl(File::Find) (version 0)
- added a new br on perl(PPI::Token::Whitespace) (version 1.203)
- added a new br on perl(charnames) (version 0)
- added a new br on perl(PPI::Document::File) (version 1.203)
- added a new br on perl(File::Spec::Unix) (version 0)
- added a new br on perl(List::Util) (version 0)
- added a new br on perl(lib) (version 0)
- added a new br on perl(Getopt::Long) (version 0)
- added a new br on perl(Exporter) (version 0)
- added a new br on perl(Test::More) (version 0)
- added a new br on perl(overload) (version 0)
- added a new br on perl(base) (version 0)
- added a new br on perl(version) (version 0)
- added a new br on perl(Carp) (version 0)
- added a new br on perl(warnings) (version 0)
- added a new br on perl(PPI::Document) (version 1.203)
- added a new br on perl(File::Basename) (version 0)
- added a new br on perl(PPI::Token::Quote::Single) (version 1.203)
- added a new br on perl(File::Spec) (version 0)
- added a new br on perl(File::Path) (version 0)
- added a new br on perl(Pod::PlainText) (version 0)
- added a new br on perl(Pod::Select) (version 0)
- added a new br on perl(PPI::Node) (version 1.203)
- added a new br on perl(English) (version 0)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1.092-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Sep 08 2008 Chris Weyl <cweyl@alumni.drew.edu> 1.092-1
- update to 1.092

* Sun Mar 09 2008 Chris Weyl <cweyl@alumni.drew.edu> 1.082-1
- update to 1.082
- resolve BZ#431577
- add t/ examples/ extras/ tools/, and filter

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.080-3
- Rebuild for perl 5.10 (again)

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.080-2
- add missing BR: perl-Exception-Class

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.080-1
- bump to 1.080

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.053-2
- rebuild for new perl

* Sat Jun 16 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.053-1
- Update to 1.053.

* Tue Mar 20 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.05-1
- Update to 1.05.

* Thu Feb 15 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.03-1
- Update to 1.03.

* Fri Jan 26 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.01-2
- Bumping release (forgot to commit sources and .cvsignore changes).

* Fri Jan 26 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.01-1
- Update to 1.01.
- New build requirement: perl(Test::Memory::Cycle).

* Thu Jan 25 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-2
- perl(Set::Scalar) is no longer required.

* Wed Jan 24 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-1
- Update to 0.23.
- New requirement: perl(B::Keywords).
- Author tests coverage improved.

* Sun Dec 17 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.22-2
- Enabled author tests.
- BR perl(HomeDir).

* Sun Dec 17 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.22-1
- Update to 0.22.

* Sat Nov 11 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.21-1
- Update to 0.21.
- New BR: perl(Set::Scalar).

* Sat Sep 16 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.2-1
- First build.
